@@ -1,7 +1,8 @@
 from dataclasses import dataclass
+from typing import TYPE_CHECKING, Iterable, List
 
-from typing import TYPE_CHECKING, List, Iterable
 from sphinxcontrib.bibtex.style.template import join
+
 from . import BaseReferenceStyle
 
 if TYPE_CHECKING:
@@ -14,7 +15,7 @@ class ExtraEmptyReferenceStyle(BaseReferenceStyle):
     """A style which generates nothing, similar to LaTeX's nocite."""
 
     def role_names(self) -> Iterable[str]:
-        return ['empty']
+        return ["empty"]
 
     def outer(self, role_name: str, children: List["BaseText"]) -> "Node":
         return join
